@@ -170,8 +170,8 @@ ServerResponse SessionThread::parseResponse(const QByteArray &resp)
     QByteArray response(resp);
 
     // Remove useless CRLF
-    int indexOfCR = response.indexOf("\r");
-    int indexOfLF = response.indexOf("\n");
+    const int indexOfCR = response.indexOf("\r");
+    const int indexOfLF = response.indexOf("\n");
 
     if (indexOfCR > 0) {
         response.truncate(indexOfCR);
@@ -181,7 +181,7 @@ ServerResponse SessionThread::parseResponse(const QByteArray &resp)
     }
 
     // Server response code
-    QByteArray code = response.left(3);
+    const QByteArray code = response.left(3);
     bool ok = false;
     const int returnCode = code.toInt(&ok);
     if (!ok) {
@@ -211,11 +211,9 @@ void SessionThread::sslConnected()
     QMutexLocker locker(&m_mutex);
     QSslCipher cipher = m_socket->sessionCipher();
 
-    if (!m_socket->sslHandshakeErrors().isEmpty()
-        || !m_socket->isEncrypted() || cipher.isNull() || cipher.usedBits() == 0) {
+    if (!m_socket->sslHandshakeErrors().isEmpty() || !m_socket->isEncrypted() || cipher.isNull() || cipher.usedBits() == 0) {
         qCDebug(KSMTP_LOG) << "Initial SSL handshake failed. cipher.isNull() is" << cipher.isNull() << ", cipher.usedBits() is" << cipher.usedBits()
-                           << ", the socket says:" << m_socket->errorString() << "and the list of SSL errors contains"
-                           << m_socket->sslHandshakeErrors().count()
+                           << ", the socket says:" << m_socket->errorString() << "and the list of SSL errors contains" << m_socket->sslHandshakeErrors().count()
                            << "items.";
         KSslErrorUiData errorData(m_socket.get());
         Q_EMIT sslError(errorData);
